//----------------------------------------------------------
// Hook into the Visio Services WebPart event and set the eventhandlers
//----------------------------------------------------------

// Hook into the AJAX Sys.Application.load event.
Sys.Application.add_load(onApplicationLoad)

// Declare global variables.
var vwaControl;
var vwaPage;
var vwaShapes;
var vwaShapeCount;

// When the application loads, set the current control and attach the event handlers we need
function onApplicationLoad() {
    var webPartId = getVWAWebPartID();
    if (webPartId == null) {
        return;
    }

    vwaControl = new Vwa.VwaControl(getVWAWebPartID());
    vwaControl.addHandler("diagramcomplete", onDiagramComplete);
    vwaControl.addHandler("shapeselectionchanged", onShapeSelectionChangedHandler);
    vwaControl.addHandler("shapemouseenter", onShapeMouseEnter);
    vwaControl.addHandler("shapemouseleave", onShapeMouseLeave);
}

// Determine the ID of the Visio Services WebPart. Be aware, the first Visio Services WebPart will be returned!
function getVWAWebPartID() {
    var visioWebParts = $("div.VisioWebAccess");
    if (visioWebParts.size() > 0) {
        return visioWebParts[0].parentNode.parentNode.id;
    }
    return null;
}

//----------------------------------------------------------
// Events of the Visio Services WebPart
//----------------------------------------------------------

// When the diagram is loaded
function onDiagramComplete() {
    vwaPage = vwaControl.getActivePage();
    vwaShapes = vwaPage.getShapes();
    vwaShapeCount = vwaShapes.getCount();

    vwaPage.setZoom(-1); // force the initial zoom level

    LoadRoomSelect();
    LoadFloorSelect();

    $("input#ButtonZoeken").click(function () {
        SearchClick();
    });

    $("input#kamer").each(function () {
        $(this).attr("onchange", "RoomSelectChange(this)");
    });
}

// When a mouse enter event is triggered on a shape
function onShapeMouseEnter(source, args) {
    ShowShapeInformationPopup(args);
}

// When a mouse leave event is triggered on a shape
function onShapeMouseLeave(source, args) {
    HideShapeInformationPopup(args);
}

// When a click event is triggered within the diagram
function onShapeSelectionChangedHandler(source, args) {
    $("select#kamer").val(args);
}

//----------------------------------------------------------
// Show rooms
//----------------------------------------------------------

// Populate the rooms select with available rooms from diagram
function LoadRoomSelect() {
    var select = document.getElementById("kamer");
    var rooms = GetRooms();

    // Show the rooms in the drop down box
    select.options.length = 0;
    select.options[select.options.length] = new Option("Maak een keuze...", "-1");
    for (i = 0; i < rooms.length; i++) {
        select.options[select.options.length] = new Option(rooms[i].getShapeDataValue("Title"), rooms[i].getId());
    }
}

// Retreive rooms from Visio
function GetRooms() {
    var roomArray = new Array();

    // Search shape based on label and value
    for (var nextShapeIndex = 0; nextShapeIndex < vwaShapeCount; nextShapeIndex++) {
        var nextShape = vwaShapes.getItemAtIndex(nextShapeIndex);
        if (nextShape.getShapeData().length > 0) {
            roomArray[roomArray.length] = nextShape;
        }
    }
    return roomArray;
}

// Retreive data label from Visio Shape
Vwa.Shape.prototype.getShapeDataValue = function (label) {
    var data = this.getShapeData();

    for (var j = 0; j < data.length; j++)
        if (data[j].label == label)
            return data[j].value;

    return null;
}

//----------------------------------------------------------
// Select room by dropdown change
//----------------------------------------------------------

// Catch event of dropdown
function RoomSelectChange(dropdown) {
    vwaPage.setSelectedShape(dropdown.value);
}


//----------------------------------------------------------
// Search for rooms
//----------------------------------------------------------

// Catch event of dropdown
function SearchClick() {
    RemoveHighlights();
    var numberPersons = document.getElementById("AantalPersonen").value;
    var needBeamer = document.getElementById("NeedBeamer").checked;
    var needRoundTable = document.getElementById("NeedRoundTable").checked;

    if (numberPersons == "") {
        alert("Geef het aantal personen op!");
        return;
    }

    var rooms = GetRooms();
    for (var i = 0; i < rooms.length; i++) {
        var room = rooms[i];
        if (parseInt(room.getShapeDataValue("Capacity")) < parseInt(numberPersons)) {
            continue;
        }
        if (needBeamer && room.getShapeDataValue("Beamer") == 0) {
            continue;
        }
        if (needRoundTable && room.getShapeDataValue("Roundtable") == 0) {
            continue;
        }
        room.addHighlight(3, 'green');
    }
}

//----------------------------------------------------------
// Remove highlights for rooms
//----------------------------------------------------------

// Remove highlights made in the diagram
function RemoveHighlights() {
    // clean up any existing highlights before we highlight other choices
    for (var nextShapeIndex = 0; nextShapeIndex < vwaShapeCount; nextShapeIndex++) {
        var nextShape = vwaShapes.getItemAtIndex(nextShapeIndex);
        nextShape.removeHighlight();
    }
}
//----------------------------------------------------------
// Add overlay for room based on XAML per room, remove when remove is set to false
//----------------------------------------------------------

//Shows the shape information popup for the current shape
function ShowShapeInformationPopup(shapeId) {
    var shape = vwaShapes.getItemById(shapeId);

    if (shape.getShapeData().length > 0) {
        shape.addOverlayXAML(false);
        shape.addOverlayImage(false);
    }
}

// Add XAML overlay
Vwa.Shape.prototype.addOverlayXAML = function (remove) {
    // get the data to display for the selected shape
    var popupText = XAMLPopup.replace("[Room]", this.getShapeDataValue("Title"));
    popupText = popupText.replace("[Capacity]", this.getShapeDataValue("Capacity"));
    popupText = popupText.replace("[Beamer]", (this.getShapeDataValue("Beamer") == 1 ? "Ja" : "Nee"));
    popupText = popupText.replace("[Round table]", (this.getShapeDataValue("Roundtable") == 1 ? "Ja" : "Nee"));

    var overlayId = "myOverlay_xaml_" + this.getId();

    this.removeOverlay(overlayId);

    if (!remove)
        this.addOverlay(overlayId,
        popupText,
            Vwa.HorizontalAlignment.center,
            Vwa.VerticalAlignment.middle,
            -50,
            50);
}

// XAML overlay for room information
var XAMLPopup = "<Grid Background=\"White\">" +
		"<Grid.ColumnDefinitions>" +
		"	<ColumnDefinition Width=\"80\" />" +
		"	<ColumnDefinition Width=\"35\"/>" +
		"</Grid.ColumnDefinitions>" +
		"<Grid.RowDefinitions>" +
		"	<RowDefinition Height=\"24\"/>" +
		"	<RowDefinition Height=\"20\"/>" +
		"	<RowDefinition Height=\"20\"/>" +
		"	<RowDefinition Height=\"20\"/>" +
		"</Grid.RowDefinitions>" +
		"<!-- Borders -->" +
		"<Border Grid.Column=\"0\" Grid.Row=\"0\" Grid.ColumnSpan=\"2\" Background=\"DarkGray\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"0\" Grid.Row=\"1\" Background=\"LightGray\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\"  />" +
		"<Border Grid.Column=\"0\" Grid.Row=\"2\" Background=\"LightGray\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"0\" Grid.Row=\"3\" Background=\"LightGray\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"0\" Grid.Row=\"4\" Background=\"LightGray\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"1\" Grid.Row=\"1\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\"  />" +
		"<Border Grid.Column=\"2\" Grid.Row=\"2\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"3\" Grid.Row=\"3\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"4\" Grid.Row=\"4\" BorderThickness=\"0,0,0,1\" BorderBrush=\"Black\" />" +
		"<Border Grid.Column=\"0\" Grid.Row=\"0\" Grid.ColumnSpan=\"2\" Grid.RowSpan=\"5\" BorderThickness=\"1,1,1,0\" BorderBrush=\"Black\" />" +
		"<!-- Text values -->" +
		"<TextBlock Height=\"24\" Margin=\"0,0,0,0\" Padding=\"5,0,0,0\" TextWrapping=\"Wrap\" Text=\"[Room]\" VerticalAlignment=\"Bottom\" FontSize=\"14\" FontWeight=\"Bold\" Grid.Row=\"0\" Grid.Column=\"0\" Grid.ColumnSpan=\"2\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"Capacity\" VerticalAlignment=\"Bottom\" FontSize=\"12\" FontWeight=\"Bold\" Grid.Row=\"1\" Grid.Column=\"0\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"Beamer\" VerticalAlignment=\"Bottom\" FontSize=\"12\" FontWeight=\"Bold\" Grid.Row=\"2\" Grid.Column=\"0\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"Round table\" VerticalAlignment=\"Bottom\" FontSize=\"12\" FontWeight=\"Bold\" Grid.Row=\"3\" Grid.Column=\"0\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"[Capacity]\" VerticalAlignment=\"Bottom\" FontSize=\"12\" Grid.Row=\"1\" Grid.Column=\"1\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"[Beamer]\" VerticalAlignment=\"Bottom\" FontSize=\"12\" Grid.Row=\"2\" Grid.Column=\"1\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>" +
		"<TextBlock Height=\"20\" Margin=\"0,0,0,0\" Padding=\"5,2,0,0\" TextWrapping=\"Wrap\" Text=\"[Round table]\" VerticalAlignment=\"Bottom\" FontSize=\"12\" Grid.Row=\"3\" Grid.Column=\"1\" Width=\"auto\" RenderTransformOrigin=\"0.5,0.5\" Foreground=\"Black\"/>	" +
	"</Grid>";

//----------------------------------------------------------
// Remove overlay for room based on XAML per room, remove when remove is set to false
//----------------------------------------------------------

// Hides the shape information popup for the current shape
function HideShapeInformationPopup(shapeId) {
    // get the selected shape from the shapes on the page
    var shape = vwaShapes.getItemById(shapeId);
    if (shape.getShapeData().length > 0) {
        shape.addOverlayXAML(true);
        shape.addOverlayImage(true);
    }
}

//----------------------------------------------------------
// Add image overlay for room based on XAML per room, remove when remove is set to false
//----------------------------------------------------------

// Add image overlay per room to show room setup
Vwa.Shape.prototype.addOverlayImage = function (remove) {
    var overlayId = "myOverlay_image_" + this.getId();
    var roomType = this.getShapeDataValue("Setup");

    if (roomType != null && roomType != "") {
        var imageUrl = window.location.protocol + "//" + window.location.hostname + "/_layouts/Connections/images/";
        if (roomType.toLowerCase() == "boardroom") {
            imageUrl += "boardroom.png";
        }
        else if (roomType.toLowerCase() == "class") {
            imageUrl += "class.png";
        }
        else if (roomType.toLowerCase() == "theater") {
            imageUrl += "theater.png";
        }
        else {
            imageUrl += "u.png";
        }

        this.removeOverlay(overlayId);
        if (!remove) {
            this.addPredefinedOverlay(
            Vwa.OverlayType.image,
            overlayId,
            imageUrl,
            Vwa.HorizontalAlignment.left,
            Vwa.VerticalAlignment.middle);
        }
    }
}

//----------------------------------------------------------
// Show floors
//----------------------------------------------------------

// Populate the floor select with page ids from diagram
function LoadFloorSelect() {
    // Show the floors in the drop down box
    var select = document.getElementById("verdieping");

    if (select.options.length == 0) {
        var floorArray = vwaControl.getAllPageIds();
        for (var i in floorArray) {
            select.options[select.options.length] = new Option(floorArray[i], floorArray[i]);
        }
    }
}

//----------------------------------------------------------
// Add logic to support multiple floors
//----------------------------------------------------------

//Set page based on selected id in dropdown
function SetSelectedPageBySelectChange(dropdown) {
    // Set active page
    vwaControl.setActivePage(dropdown.value);
}
